Installation
------------

As usual, that is::

    pip install invenio-explicit-acls

To use development version (NOT recommended, use with extra care!)::

    pip install git+https://github.com/oarepo/invenio-explicit-acls.git

Do not forget to initialize database tables with::

    invenio db init create

